# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_DILATE_METADATA = Metadata(
    id="c7cf27ddf3bd9107f4ebe78ae6eb1975ae7f12ba.boutiques",
    name="volume-dilate",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeDilatePresmoothParameters = typing.TypedDict('VolumeDilatePresmoothParameters', {
    "@type": typing.NotRequired[typing.Literal["presmooth"]],
    "kernel": float,
    "opt_fwhm": bool,
})
VolumeDilatePresmoothParametersTagged = typing.TypedDict('VolumeDilatePresmoothParametersTagged', {
    "@type": typing.Literal["presmooth"],
    "kernel": float,
    "opt_fwhm": bool,
})


VolumeDilateGradExtrapolateParameters = typing.TypedDict('VolumeDilateGradExtrapolateParameters', {
    "@type": typing.NotRequired[typing.Literal["grad_extrapolate"]],
    "presmooth": typing.NotRequired[VolumeDilatePresmoothParameters | None],
})
VolumeDilateGradExtrapolateParametersTagged = typing.TypedDict('VolumeDilateGradExtrapolateParametersTagged', {
    "@type": typing.Literal["grad_extrapolate"],
    "presmooth": typing.NotRequired[VolumeDilatePresmoothParameters | None],
})


VolumeDilateParameters = typing.TypedDict('VolumeDilateParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-dilate"]],
    "volume": InputPathType,
    "distance": float,
    "method": str,
    "volume_out": str,
    "opt_exponent_exponent": typing.NotRequired[float | None],
    "opt_bad_voxel_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "opt_data_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "opt_subvolume_subvol": typing.NotRequired[str | None],
    "opt_legacy_cutoff": bool,
    "grad_extrapolate": typing.NotRequired[VolumeDilateGradExtrapolateParameters | None],
})
VolumeDilateParametersTagged = typing.TypedDict('VolumeDilateParametersTagged', {
    "@type": typing.Literal["workbench/volume-dilate"],
    "volume": InputPathType,
    "distance": float,
    "method": str,
    "volume_out": str,
    "opt_exponent_exponent": typing.NotRequired[float | None],
    "opt_bad_voxel_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "opt_data_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "opt_subvolume_subvol": typing.NotRequired[str | None],
    "opt_legacy_cutoff": bool,
    "grad_extrapolate": typing.NotRequired[VolumeDilateGradExtrapolateParameters | None],
})


def volume_dilate_presmooth_params(
    kernel: float,
    opt_fwhm: bool = False,
) -> VolumeDilatePresmoothParametersTagged:
    """
    Build parameters.
    
    Args:
        kernel: the size of gaussian smoothing kernel in mm, as sigma by\
            default.
        opt_fwhm: kernel size is FWHM, not sigma.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "presmooth",
        "kernel": kernel,
        "opt_fwhm": opt_fwhm,
    }
    return params


def volume_dilate_presmooth_cargs(
    params: VolumeDilatePresmoothParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-presmooth")
    cargs.append(str(params.get("kernel", None)))
    if params.get("opt_fwhm", False):
        cargs.append("-fwhm")
    return cargs


def volume_dilate_grad_extrapolate_params(
    presmooth: VolumeDilatePresmoothParameters | None = None,
) -> VolumeDilateGradExtrapolateParametersTagged:
    """
    Build parameters.
    
    Args:
        presmooth: apply presmoothing before computing gradient vectors, not\
            recommended.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "grad_extrapolate",
    }
    if presmooth is not None:
        params["presmooth"] = presmooth
    return params


def volume_dilate_grad_extrapolate_cargs(
    params: VolumeDilateGradExtrapolateParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-grad-extrapolate")
    if params.get("presmooth", None) is not None:
        cargs.extend(volume_dilate_presmooth_cargs(params.get("presmooth", None), execution))
    return cargs


class VolumeDilateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeDilateParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_dilate_params(
    volume: InputPathType,
    distance: float,
    method: str,
    volume_out: str,
    opt_exponent_exponent: float | None = None,
    opt_bad_voxel_roi_roi_volume: InputPathType | None = None,
    opt_data_roi_roi_volume: InputPathType | None = None,
    opt_subvolume_subvol: str | None = None,
    opt_legacy_cutoff: bool = False,
    grad_extrapolate: VolumeDilateGradExtrapolateParameters | None = None,
) -> VolumeDilateParametersTagged:
    """
    Build parameters.
    
    Args:
        volume: the volume to dilate.
        distance: distance in mm to dilate.
        method: dilation method to use.
        volume_out: the output volume.
        opt_exponent_exponent: use a different exponent in the weighting\
            function: exponent 'n' to use in (1 / (distance ^ n)) as the weighting\
            function (default 7).
        opt_bad_voxel_roi_roi_volume: specify an roi of voxels to overwrite,\
            rather than voxels with value zero: volume file, positive values denote\
            voxels to have their values replaced.
        opt_data_roi_roi_volume: specify an roi of where there is data: volume\
            file, positive values denote voxels that have data.
        opt_subvolume_subvol: select a single subvolume to dilate: the\
            subvolume number or name.
        opt_legacy_cutoff: use the v1.3.2 method of excluding voxels further\
            than the dilation distance when calculating the dilated value.
        grad_extrapolate: additionally use the gradient to extrapolate,\
            intended to be used with WEIGHTED.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-dilate",
        "volume": volume,
        "distance": distance,
        "method": method,
        "volume_out": volume_out,
        "opt_legacy_cutoff": opt_legacy_cutoff,
    }
    if opt_exponent_exponent is not None:
        params["opt_exponent_exponent"] = opt_exponent_exponent
    if opt_bad_voxel_roi_roi_volume is not None:
        params["opt_bad_voxel_roi_roi_volume"] = opt_bad_voxel_roi_roi_volume
    if opt_data_roi_roi_volume is not None:
        params["opt_data_roi_roi_volume"] = opt_data_roi_roi_volume
    if opt_subvolume_subvol is not None:
        params["opt_subvolume_subvol"] = opt_subvolume_subvol
    if grad_extrapolate is not None:
        params["grad_extrapolate"] = grad_extrapolate
    return params


def volume_dilate_cargs(
    params: VolumeDilateParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-dilate")
    cargs.append(execution.input_file(params.get("volume", None)))
    cargs.append(str(params.get("distance", None)))
    cargs.append(params.get("method", None))
    cargs.append(params.get("volume_out", None))
    if params.get("opt_exponent_exponent", None) is not None:
        cargs.extend([
            "-exponent",
            str(params.get("opt_exponent_exponent", None))
        ])
    if params.get("opt_bad_voxel_roi_roi_volume", None) is not None:
        cargs.extend([
            "-bad-voxel-roi",
            execution.input_file(params.get("opt_bad_voxel_roi_roi_volume", None))
        ])
    if params.get("opt_data_roi_roi_volume", None) is not None:
        cargs.extend([
            "-data-roi",
            execution.input_file(params.get("opt_data_roi_roi_volume", None))
        ])
    if params.get("opt_subvolume_subvol", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("opt_subvolume_subvol", None)
        ])
    if params.get("opt_legacy_cutoff", False):
        cargs.append("-legacy-cutoff")
    if params.get("grad_extrapolate", None) is not None:
        cargs.extend(volume_dilate_grad_extrapolate_cargs(params.get("grad_extrapolate", None), execution))
    return cargs


def volume_dilate_outputs(
    params: VolumeDilateParameters,
    execution: Execution,
) -> VolumeDilateOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeDilateOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_dilate_execute(
    params: VolumeDilateParameters,
    runner: Runner | None = None,
) -> VolumeDilateOutputs:
    """
    volume-dilate
    
    Dilate a volume file.
    
    For all voxels that are designated as bad, if they neighbor a non-bad voxel
    with data or are within the specified distance of such a voxel, replace the
    value in the bad voxel with a value calculated from nearby non-bad voxels
    that have data, otherwise set the value to zero. No matter how small
    <distance> is, dilation will always use at least the face neighbor voxels.
    
    By default, voxels that have data with the value 0 are bad, specify
    -bad-voxel-roi to only count voxels as bad if they are selected by the roi.
    If -data-roi is not specified, all voxels are assumed to have data.
    
    To get the behavior of version 1.3.2 or earlier, use '-legacy-cutoff
    -exponent 2'.
    
    Valid values for <method> are:
    
    NEAREST - use the value from the nearest good voxel
    WEIGHTED - use a weighted average based on distance.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeDilateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_DILATE_METADATA)
    params = execution.params(params)
    cargs = volume_dilate_cargs(params, execution)
    ret = volume_dilate_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_dilate(
    volume: InputPathType,
    distance: float,
    method: str,
    volume_out: str,
    opt_exponent_exponent: float | None = None,
    opt_bad_voxel_roi_roi_volume: InputPathType | None = None,
    opt_data_roi_roi_volume: InputPathType | None = None,
    opt_subvolume_subvol: str | None = None,
    opt_legacy_cutoff: bool = False,
    grad_extrapolate: VolumeDilateGradExtrapolateParameters | None = None,
    runner: Runner | None = None,
) -> VolumeDilateOutputs:
    """
    volume-dilate
    
    Dilate a volume file.
    
    For all voxels that are designated as bad, if they neighbor a non-bad voxel
    with data or are within the specified distance of such a voxel, replace the
    value in the bad voxel with a value calculated from nearby non-bad voxels
    that have data, otherwise set the value to zero. No matter how small
    <distance> is, dilation will always use at least the face neighbor voxels.
    
    By default, voxels that have data with the value 0 are bad, specify
    -bad-voxel-roi to only count voxels as bad if they are selected by the roi.
    If -data-roi is not specified, all voxels are assumed to have data.
    
    To get the behavior of version 1.3.2 or earlier, use '-legacy-cutoff
    -exponent 2'.
    
    Valid values for <method> are:
    
    NEAREST - use the value from the nearest good voxel
    WEIGHTED - use a weighted average based on distance.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume: the volume to dilate.
        distance: distance in mm to dilate.
        method: dilation method to use.
        volume_out: the output volume.
        opt_exponent_exponent: use a different exponent in the weighting\
            function: exponent 'n' to use in (1 / (distance ^ n)) as the weighting\
            function (default 7).
        opt_bad_voxel_roi_roi_volume: specify an roi of voxels to overwrite,\
            rather than voxels with value zero: volume file, positive values denote\
            voxels to have their values replaced.
        opt_data_roi_roi_volume: specify an roi of where there is data: volume\
            file, positive values denote voxels that have data.
        opt_subvolume_subvol: select a single subvolume to dilate: the\
            subvolume number or name.
        opt_legacy_cutoff: use the v1.3.2 method of excluding voxels further\
            than the dilation distance when calculating the dilated value.
        grad_extrapolate: additionally use the gradient to extrapolate,\
            intended to be used with WEIGHTED.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeDilateOutputs`).
    """
    params = volume_dilate_params(
        volume=volume,
        distance=distance,
        method=method,
        volume_out=volume_out,
        opt_exponent_exponent=opt_exponent_exponent,
        opt_bad_voxel_roi_roi_volume=opt_bad_voxel_roi_roi_volume,
        opt_data_roi_roi_volume=opt_data_roi_roi_volume,
        opt_subvolume_subvol=opt_subvolume_subvol,
        opt_legacy_cutoff=opt_legacy_cutoff,
        grad_extrapolate=grad_extrapolate,
    )
    return volume_dilate_execute(params, runner)


__all__ = [
    "VOLUME_DILATE_METADATA",
    "VolumeDilateOutputs",
    "volume_dilate",
    "volume_dilate_execute",
    "volume_dilate_grad_extrapolate_params",
    "volume_dilate_params",
    "volume_dilate_presmooth_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

GIFTI_LABEL_TO_ROI_METADATA = Metadata(
    id="5c48bae6e2e86735376fa584af53363f5564f875.boutiques",
    name="gifti-label-to-roi",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


GiftiLabelToRoiParameters = typing.TypedDict('GiftiLabelToRoiParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/gifti-label-to-roi"]],
    "label_in": InputPathType,
    "metric_out": str,
    "opt_name_label_name": typing.NotRequired[str | None],
    "opt_key_label_key": typing.NotRequired[int | None],
    "opt_map_map": typing.NotRequired[str | None],
})
GiftiLabelToRoiParametersTagged = typing.TypedDict('GiftiLabelToRoiParametersTagged', {
    "@type": typing.Literal["workbench/gifti-label-to-roi"],
    "label_in": InputPathType,
    "metric_out": str,
    "opt_name_label_name": typing.NotRequired[str | None],
    "opt_key_label_key": typing.NotRequired[int | None],
    "opt_map_map": typing.NotRequired[str | None],
})


class GiftiLabelToRoiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `GiftiLabelToRoiParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric file"""


def gifti_label_to_roi_params(
    label_in: InputPathType,
    metric_out: str,
    opt_name_label_name: str | None = None,
    opt_key_label_key: int | None = None,
    opt_map_map: str | None = None,
) -> GiftiLabelToRoiParametersTagged:
    """
    Build parameters.
    
    Args:
        label_in: the input gifti label file.
        metric_out: the output metric file.
        opt_name_label_name: select label by name: the label name that you want\
            an roi of.
        opt_key_label_key: select label by key: the label key that you want an\
            roi of.
        opt_map_map: select a single label map to use: the map number or name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/gifti-label-to-roi",
        "label_in": label_in,
        "metric_out": metric_out,
    }
    if opt_name_label_name is not None:
        params["opt_name_label_name"] = opt_name_label_name
    if opt_key_label_key is not None:
        params["opt_key_label_key"] = opt_key_label_key
    if opt_map_map is not None:
        params["opt_map_map"] = opt_map_map
    return params


def gifti_label_to_roi_cargs(
    params: GiftiLabelToRoiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-gifti-label-to-roi")
    cargs.append(execution.input_file(params.get("label_in", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_name_label_name", None) is not None:
        cargs.extend([
            "-name",
            params.get("opt_name_label_name", None)
        ])
    if params.get("opt_key_label_key", None) is not None:
        cargs.extend([
            "-key",
            str(params.get("opt_key_label_key", None))
        ])
    if params.get("opt_map_map", None) is not None:
        cargs.extend([
            "-map",
            params.get("opt_map_map", None)
        ])
    return cargs


def gifti_label_to_roi_outputs(
    params: GiftiLabelToRoiParameters,
    execution: Execution,
) -> GiftiLabelToRoiOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = GiftiLabelToRoiOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def gifti_label_to_roi_execute(
    params: GiftiLabelToRoiParameters,
    runner: Runner | None = None,
) -> GiftiLabelToRoiOutputs:
    """
    gifti-label-to-roi
    
    Make a gifti label into an roi metric.
    
    For each map in <label-in>, a map is created in <metric-out> where all
    locations labeled with <label-name> or with a key of <label-key> are given a
    value of 1, and all other locations are given 0. Exactly one of -name and
    -key must be specified. Specify -map to use only one map from <label-in>.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiLabelToRoiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GIFTI_LABEL_TO_ROI_METADATA)
    params = execution.params(params)
    cargs = gifti_label_to_roi_cargs(params, execution)
    ret = gifti_label_to_roi_outputs(params, execution)
    execution.run(cargs)
    return ret


def gifti_label_to_roi(
    label_in: InputPathType,
    metric_out: str,
    opt_name_label_name: str | None = None,
    opt_key_label_key: int | None = None,
    opt_map_map: str | None = None,
    runner: Runner | None = None,
) -> GiftiLabelToRoiOutputs:
    """
    gifti-label-to-roi
    
    Make a gifti label into an roi metric.
    
    For each map in <label-in>, a map is created in <metric-out> where all
    locations labeled with <label-name> or with a key of <label-key> are given a
    value of 1, and all other locations are given 0. Exactly one of -name and
    -key must be specified. Specify -map to use only one map from <label-in>.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_in: the input gifti label file.
        metric_out: the output metric file.
        opt_name_label_name: select label by name: the label name that you want\
            an roi of.
        opt_key_label_key: select label by key: the label key that you want an\
            roi of.
        opt_map_map: select a single label map to use: the map number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiLabelToRoiOutputs`).
    """
    params = gifti_label_to_roi_params(
        label_in=label_in,
        metric_out=metric_out,
        opt_name_label_name=opt_name_label_name,
        opt_key_label_key=opt_key_label_key,
        opt_map_map=opt_map_map,
    )
    return gifti_label_to_roi_execute(params, runner)


__all__ = [
    "GIFTI_LABEL_TO_ROI_METADATA",
    "GiftiLabelToRoiOutputs",
    "gifti_label_to_roi",
    "gifti_label_to_roi_execute",
    "gifti_label_to_roi_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SPEC_FILE_MERGE_METADATA = Metadata(
    id="dc8ed74b03797d25ba546c4df5d98037f0153fa7.boutiques",
    name="spec-file-merge",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SpecFileMergeParameters = typing.TypedDict('SpecFileMergeParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/spec-file-merge"]],
    "spec_1": str,
    "spec_2": str,
    "out_spec": str,
})
SpecFileMergeParametersTagged = typing.TypedDict('SpecFileMergeParametersTagged', {
    "@type": typing.Literal["workbench/spec-file-merge"],
    "spec_1": str,
    "spec_2": str,
    "out_spec": str,
})


class SpecFileMergeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SpecFileMergeParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def spec_file_merge_params(
    spec_1: str,
    spec_2: str,
    out_spec: str,
) -> SpecFileMergeParametersTagged:
    """
    Build parameters.
    
    Args:
        spec_1: first spec file to merge.
        spec_2: second spec file to merge.
        out_spec: output - output spec file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/spec-file-merge",
        "spec_1": spec_1,
        "spec_2": spec_2,
        "out_spec": out_spec,
    }
    return params


def spec_file_merge_cargs(
    params: SpecFileMergeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-spec-file-merge")
    cargs.append(params.get("spec_1", None))
    cargs.append(params.get("spec_2", None))
    cargs.append(params.get("out_spec", None))
    return cargs


def spec_file_merge_outputs(
    params: SpecFileMergeParameters,
    execution: Execution,
) -> SpecFileMergeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SpecFileMergeOutputs(
        root=execution.output_file("."),
    )
    return ret


def spec_file_merge_execute(
    params: SpecFileMergeParameters,
    runner: Runner | None = None,
) -> SpecFileMergeOutputs:
    """
    spec-file-merge
    
    Merge two spec files into one.
    
    The output spec file contains every file that is in either of the input spec
    files.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SpecFileMergeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPEC_FILE_MERGE_METADATA)
    params = execution.params(params)
    cargs = spec_file_merge_cargs(params, execution)
    ret = spec_file_merge_outputs(params, execution)
    execution.run(cargs)
    return ret


def spec_file_merge(
    spec_1: str,
    spec_2: str,
    out_spec: str,
    runner: Runner | None = None,
) -> SpecFileMergeOutputs:
    """
    spec-file-merge
    
    Merge two spec files into one.
    
    The output spec file contains every file that is in either of the input spec
    files.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        spec_1: first spec file to merge.
        spec_2: second spec file to merge.
        out_spec: output - output spec file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SpecFileMergeOutputs`).
    """
    params = spec_file_merge_params(
        spec_1=spec_1,
        spec_2=spec_2,
        out_spec=out_spec,
    )
    return spec_file_merge_execute(params, runner)


__all__ = [
    "SPEC_FILE_MERGE_METADATA",
    "SpecFileMergeOutputs",
    "spec_file_merge",
    "spec_file_merge_execute",
    "spec_file_merge_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_AFFINE_REGRESSION_METADATA = Metadata(
    id="250a34f2b42b75612a852d89d3d7eb774e8fa266.boutiques",
    name="surface-affine-regression",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceAffineRegressionParameters = typing.TypedDict('SurfaceAffineRegressionParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-affine-regression"]],
    "source": InputPathType,
    "target": InputPathType,
    "affine_out": str,
})
SurfaceAffineRegressionParametersTagged = typing.TypedDict('SurfaceAffineRegressionParametersTagged', {
    "@type": typing.Literal["workbench/surface-affine-regression"],
    "source": InputPathType,
    "target": InputPathType,
    "affine_out": str,
})


class SurfaceAffineRegressionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceAffineRegressionParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surface_affine_regression_params(
    source: InputPathType,
    target: InputPathType,
    affine_out: str,
) -> SurfaceAffineRegressionParametersTagged:
    """
    Build parameters.
    
    Args:
        source: the surface to warp.
        target: the surface to match the coordinates of.
        affine_out: output - the output affine file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-affine-regression",
        "source": source,
        "target": target,
        "affine_out": affine_out,
    }
    return params


def surface_affine_regression_cargs(
    params: SurfaceAffineRegressionParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-affine-regression")
    cargs.append(execution.input_file(params.get("source", None)))
    cargs.append(execution.input_file(params.get("target", None)))
    cargs.append(params.get("affine_out", None))
    return cargs


def surface_affine_regression_outputs(
    params: SurfaceAffineRegressionParameters,
    execution: Execution,
) -> SurfaceAffineRegressionOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceAffineRegressionOutputs(
        root=execution.output_file("."),
    )
    return ret


def surface_affine_regression_execute(
    params: SurfaceAffineRegressionParameters,
    runner: Runner | None = None,
) -> SurfaceAffineRegressionOutputs:
    """
    surface-affine-regression
    
    Regress the affine transform between surfaces on the same mesh.
    
    Use linear regression to compute an affine that minimizes the sum of squares
    of the coordinate differences between the target surface and the warped
    source surface. Note that this has a bias to shrink the surface that is
    being warped. The output is written as a NIFTI 'world' matrix, see
    -convert-affine to convert it for use in other software.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceAffineRegressionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_AFFINE_REGRESSION_METADATA)
    params = execution.params(params)
    cargs = surface_affine_regression_cargs(params, execution)
    ret = surface_affine_regression_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_affine_regression(
    source: InputPathType,
    target: InputPathType,
    affine_out: str,
    runner: Runner | None = None,
) -> SurfaceAffineRegressionOutputs:
    """
    surface-affine-regression
    
    Regress the affine transform between surfaces on the same mesh.
    
    Use linear regression to compute an affine that minimizes the sum of squares
    of the coordinate differences between the target surface and the warped
    source surface. Note that this has a bias to shrink the surface that is
    being warped. The output is written as a NIFTI 'world' matrix, see
    -convert-affine to convert it for use in other software.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        source: the surface to warp.
        target: the surface to match the coordinates of.
        affine_out: output - the output affine file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceAffineRegressionOutputs`).
    """
    params = surface_affine_regression_params(
        source=source,
        target=target,
        affine_out=affine_out,
    )
    return surface_affine_regression_execute(params, runner)


__all__ = [
    "SURFACE_AFFINE_REGRESSION_METADATA",
    "SurfaceAffineRegressionOutputs",
    "surface_affine_regression",
    "surface_affine_regression_execute",
    "surface_affine_regression_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_CREATE_PARCELLATED_FROM_TEMPLATE_METADATA = Metadata(
    id="5ab4304888f5759b5c4b5e4ccb61651a79d1f737.boutiques",
    name="cifti-create-parcellated-from-template",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiCreateParcellatedFromTemplateCiftiParameters = typing.TypedDict('CiftiCreateParcellatedFromTemplateCiftiParameters', {
    "@type": typing.NotRequired[typing.Literal["cifti"]],
    "cifti_in": InputPathType,
})
CiftiCreateParcellatedFromTemplateCiftiParametersTagged = typing.TypedDict('CiftiCreateParcellatedFromTemplateCiftiParametersTagged', {
    "@type": typing.Literal["cifti"],
    "cifti_in": InputPathType,
})


CiftiCreateParcellatedFromTemplateParameters = typing.TypedDict('CiftiCreateParcellatedFromTemplateParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-create-parcellated-from-template"]],
    "cifti_template": InputPathType,
    "modify_direction": str,
    "cifti_out": str,
    "opt_fill_value_value": typing.NotRequired[float | None],
    "cifti": typing.NotRequired[list[CiftiCreateParcellatedFromTemplateCiftiParameters] | None],
})
CiftiCreateParcellatedFromTemplateParametersTagged = typing.TypedDict('CiftiCreateParcellatedFromTemplateParametersTagged', {
    "@type": typing.Literal["workbench/cifti-create-parcellated-from-template"],
    "cifti_template": InputPathType,
    "modify_direction": str,
    "cifti_out": str,
    "opt_fill_value_value": typing.NotRequired[float | None],
    "cifti": typing.NotRequired[list[CiftiCreateParcellatedFromTemplateCiftiParameters] | None],
})


def cifti_create_parcellated_from_template_cifti_params(
    cifti_in: InputPathType,
) -> CiftiCreateParcellatedFromTemplateCiftiParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input parcellated cifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cifti",
        "cifti_in": cifti_in,
    }
    return params


def cifti_create_parcellated_from_template_cifti_cargs(
    params: CiftiCreateParcellatedFromTemplateCiftiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cifti")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    return cargs


class CiftiCreateParcellatedFromTemplateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiCreateParcellatedFromTemplateParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_create_parcellated_from_template_params(
    cifti_template: InputPathType,
    modify_direction: str,
    cifti_out: str,
    opt_fill_value_value: float | None = None,
    cifti: list[CiftiCreateParcellatedFromTemplateCiftiParameters] | None = None,
) -> CiftiCreateParcellatedFromTemplateParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_template: a cifti file with the template parcel mapping along\
            column.
        modify_direction: which dimension of the output file should match the\
            template (integer, 'ROW', or 'COLUMN').
        cifti_out: the output cifti file.
        opt_fill_value_value: specify value to be used in parcels that don't\
            match: value to use (default 0).
        cifti: specify an input cifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-create-parcellated-from-template",
        "cifti_template": cifti_template,
        "modify_direction": modify_direction,
        "cifti_out": cifti_out,
    }
    if opt_fill_value_value is not None:
        params["opt_fill_value_value"] = opt_fill_value_value
    if cifti is not None:
        params["cifti"] = cifti
    return params


def cifti_create_parcellated_from_template_cargs(
    params: CiftiCreateParcellatedFromTemplateParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-create-parcellated-from-template")
    cargs.append(execution.input_file(params.get("cifti_template", None)))
    cargs.append(params.get("modify_direction", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_fill_value_value", None) is not None:
        cargs.extend([
            "-fill-value",
            str(params.get("opt_fill_value_value", None))
        ])
    if params.get("cifti", None) is not None:
        cargs.extend([a for c in [cifti_create_parcellated_from_template_cifti_cargs(s, execution) for s in params.get("cifti", None)] for a in c])
    return cargs


def cifti_create_parcellated_from_template_outputs(
    params: CiftiCreateParcellatedFromTemplateParameters,
    execution: Execution,
) -> CiftiCreateParcellatedFromTemplateOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiCreateParcellatedFromTemplateOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_create_parcellated_from_template_execute(
    params: CiftiCreateParcellatedFromTemplateParameters,
    runner: Runner | None = None,
) -> CiftiCreateParcellatedFromTemplateOutputs:
    """
    cifti-create-parcellated-from-template
    
    Match parcels to template by name.
    
    For each parcel name in the template mapping, find that name in an input
    cifti file and use its data in the output file. All input cifti files must
    have a parcels mapping along <modify-direction> and matching mappings along
    other dimensions. The direction can be either an integer starting from 1, or
    the strings 'ROW' or 'COLUMN'.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateParcellatedFromTemplateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CREATE_PARCELLATED_FROM_TEMPLATE_METADATA)
    params = execution.params(params)
    cargs = cifti_create_parcellated_from_template_cargs(params, execution)
    ret = cifti_create_parcellated_from_template_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_create_parcellated_from_template(
    cifti_template: InputPathType,
    modify_direction: str,
    cifti_out: str,
    opt_fill_value_value: float | None = None,
    cifti: list[CiftiCreateParcellatedFromTemplateCiftiParameters] | None = None,
    runner: Runner | None = None,
) -> CiftiCreateParcellatedFromTemplateOutputs:
    """
    cifti-create-parcellated-from-template
    
    Match parcels to template by name.
    
    For each parcel name in the template mapping, find that name in an input
    cifti file and use its data in the output file. All input cifti files must
    have a parcels mapping along <modify-direction> and matching mappings along
    other dimensions. The direction can be either an integer starting from 1, or
    the strings 'ROW' or 'COLUMN'.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_template: a cifti file with the template parcel mapping along\
            column.
        modify_direction: which dimension of the output file should match the\
            template (integer, 'ROW', or 'COLUMN').
        cifti_out: the output cifti file.
        opt_fill_value_value: specify value to be used in parcels that don't\
            match: value to use (default 0).
        cifti: specify an input cifti file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateParcellatedFromTemplateOutputs`).
    """
    params = cifti_create_parcellated_from_template_params(
        cifti_template=cifti_template,
        modify_direction=modify_direction,
        cifti_out=cifti_out,
        opt_fill_value_value=opt_fill_value_value,
        cifti=cifti,
    )
    return cifti_create_parcellated_from_template_execute(params, runner)


__all__ = [
    "CIFTI_CREATE_PARCELLATED_FROM_TEMPLATE_METADATA",
    "CiftiCreateParcellatedFromTemplateOutputs",
    "cifti_create_parcellated_from_template",
    "cifti_create_parcellated_from_template_cifti_params",
    "cifti_create_parcellated_from_template_execute",
    "cifti_create_parcellated_from_template_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_ROI_AVERAGE_METADATA = Metadata(
    id="d3bb8cff36344df781b7dd9dbdd7df47c80190d5.boutiques",
    name="cifti-roi-average",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiRoiAverageParameters = typing.TypedDict('CiftiRoiAverageParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-roi-average"]],
    "cifti_in": InputPathType,
    "text_out": str,
    "opt_cifti_roi_roi_cifti": typing.NotRequired[InputPathType | None],
    "opt_left_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_right_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_vol_roi_roi_vol": typing.NotRequired[InputPathType | None],
})
CiftiRoiAverageParametersTagged = typing.TypedDict('CiftiRoiAverageParametersTagged', {
    "@type": typing.Literal["workbench/cifti-roi-average"],
    "cifti_in": InputPathType,
    "text_out": str,
    "opt_cifti_roi_roi_cifti": typing.NotRequired[InputPathType | None],
    "opt_left_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_right_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_vol_roi_roi_vol": typing.NotRequired[InputPathType | None],
})


class CiftiRoiAverageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiRoiAverageParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_roi_average_params(
    cifti_in: InputPathType,
    text_out: str,
    opt_cifti_roi_roi_cifti: InputPathType | None = None,
    opt_left_roi_roi_metric: InputPathType | None = None,
    opt_right_roi_roi_metric: InputPathType | None = None,
    opt_cerebellum_roi_roi_metric: InputPathType | None = None,
    opt_vol_roi_roi_vol: InputPathType | None = None,
) -> CiftiRoiAverageParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the cifti file to average rows from.
        text_out: output text file of the average values.
        opt_cifti_roi_roi_cifti: cifti file containing combined rois: the rois\
            as a cifti file.
        opt_left_roi_roi_metric: vertices to use from left hemisphere: the left\
            roi as a metric file.
        opt_right_roi_roi_metric: vertices to use from right hemisphere: the\
            right roi as a metric file.
        opt_cerebellum_roi_roi_metric: vertices to use from cerebellum: the\
            cerebellum roi as a metric file.
        opt_vol_roi_roi_vol: voxels to use: the roi volume file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-roi-average",
        "cifti_in": cifti_in,
        "text_out": text_out,
    }
    if opt_cifti_roi_roi_cifti is not None:
        params["opt_cifti_roi_roi_cifti"] = opt_cifti_roi_roi_cifti
    if opt_left_roi_roi_metric is not None:
        params["opt_left_roi_roi_metric"] = opt_left_roi_roi_metric
    if opt_right_roi_roi_metric is not None:
        params["opt_right_roi_roi_metric"] = opt_right_roi_roi_metric
    if opt_cerebellum_roi_roi_metric is not None:
        params["opt_cerebellum_roi_roi_metric"] = opt_cerebellum_roi_roi_metric
    if opt_vol_roi_roi_vol is not None:
        params["opt_vol_roi_roi_vol"] = opt_vol_roi_roi_vol
    return params


def cifti_roi_average_cargs(
    params: CiftiRoiAverageParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-roi-average")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    cargs.append(params.get("text_out", None))
    if params.get("opt_cifti_roi_roi_cifti", None) is not None:
        cargs.extend([
            "-cifti-roi",
            execution.input_file(params.get("opt_cifti_roi_roi_cifti", None))
        ])
    if params.get("opt_left_roi_roi_metric", None) is not None:
        cargs.extend([
            "-left-roi",
            execution.input_file(params.get("opt_left_roi_roi_metric", None))
        ])
    if params.get("opt_right_roi_roi_metric", None) is not None:
        cargs.extend([
            "-right-roi",
            execution.input_file(params.get("opt_right_roi_roi_metric", None))
        ])
    if params.get("opt_cerebellum_roi_roi_metric", None) is not None:
        cargs.extend([
            "-cerebellum-roi",
            execution.input_file(params.get("opt_cerebellum_roi_roi_metric", None))
        ])
    if params.get("opt_vol_roi_roi_vol", None) is not None:
        cargs.extend([
            "-vol-roi",
            execution.input_file(params.get("opt_vol_roi_roi_vol", None))
        ])
    return cargs


def cifti_roi_average_outputs(
    params: CiftiRoiAverageParameters,
    execution: Execution,
) -> CiftiRoiAverageOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiRoiAverageOutputs(
        root=execution.output_file("."),
    )
    return ret


def cifti_roi_average_execute(
    params: CiftiRoiAverageParameters,
    runner: Runner | None = None,
) -> CiftiRoiAverageOutputs:
    """
    cifti-roi-average
    
    Average rows in a single cifti file.
    
    Average the rows that are within the specified ROIs, and write the resulting
    average row to a text file, separated by newlines. If -cifti-roi is
    specified, -left-roi, -right-roi, -cerebellum-roi, and -vol-roi must not be
    specified.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiRoiAverageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_ROI_AVERAGE_METADATA)
    params = execution.params(params)
    cargs = cifti_roi_average_cargs(params, execution)
    ret = cifti_roi_average_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_roi_average(
    cifti_in: InputPathType,
    text_out: str,
    opt_cifti_roi_roi_cifti: InputPathType | None = None,
    opt_left_roi_roi_metric: InputPathType | None = None,
    opt_right_roi_roi_metric: InputPathType | None = None,
    opt_cerebellum_roi_roi_metric: InputPathType | None = None,
    opt_vol_roi_roi_vol: InputPathType | None = None,
    runner: Runner | None = None,
) -> CiftiRoiAverageOutputs:
    """
    cifti-roi-average
    
    Average rows in a single cifti file.
    
    Average the rows that are within the specified ROIs, and write the resulting
    average row to a text file, separated by newlines. If -cifti-roi is
    specified, -left-roi, -right-roi, -cerebellum-roi, and -vol-roi must not be
    specified.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the cifti file to average rows from.
        text_out: output text file of the average values.
        opt_cifti_roi_roi_cifti: cifti file containing combined rois: the rois\
            as a cifti file.
        opt_left_roi_roi_metric: vertices to use from left hemisphere: the left\
            roi as a metric file.
        opt_right_roi_roi_metric: vertices to use from right hemisphere: the\
            right roi as a metric file.
        opt_cerebellum_roi_roi_metric: vertices to use from cerebellum: the\
            cerebellum roi as a metric file.
        opt_vol_roi_roi_vol: voxels to use: the roi volume file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiRoiAverageOutputs`).
    """
    params = cifti_roi_average_params(
        cifti_in=cifti_in,
        text_out=text_out,
        opt_cifti_roi_roi_cifti=opt_cifti_roi_roi_cifti,
        opt_left_roi_roi_metric=opt_left_roi_roi_metric,
        opt_right_roi_roi_metric=opt_right_roi_roi_metric,
        opt_cerebellum_roi_roi_metric=opt_cerebellum_roi_roi_metric,
        opt_vol_roi_roi_vol=opt_vol_roi_roi_vol,
    )
    return cifti_roi_average_execute(params, runner)


__all__ = [
    "CIFTI_ROI_AVERAGE_METADATA",
    "CiftiRoiAverageOutputs",
    "cifti_roi_average",
    "cifti_roi_average_execute",
    "cifti_roi_average_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

FIBER_DOT_PRODUCTS_METADATA = Metadata(
    id="1bea023ebc341c8821892b782bf2c571990af31a.boutiques",
    name="fiber-dot-products",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


FiberDotProductsParameters = typing.TypedDict('FiberDotProductsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/fiber-dot-products"]],
    "white_surf": InputPathType,
    "fiber_file": InputPathType,
    "max_dist": float,
    "direction": str,
    "dot_metric": str,
    "f_metric": str,
})
FiberDotProductsParametersTagged = typing.TypedDict('FiberDotProductsParametersTagged', {
    "@type": typing.Literal["workbench/fiber-dot-products"],
    "white_surf": InputPathType,
    "fiber_file": InputPathType,
    "max_dist": float,
    "direction": str,
    "dot_metric": str,
    "f_metric": str,
})


class FiberDotProductsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `FiberDotProductsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dot_metric: OutputPathType
    """the metric of dot products"""
    f_metric: OutputPathType
    """a metric of the f values of the fiber distributions"""


def fiber_dot_products_params(
    white_surf: InputPathType,
    fiber_file: InputPathType,
    max_dist: float,
    direction: str,
    dot_metric: str,
    f_metric: str,
) -> FiberDotProductsParametersTagged:
    """
    Build parameters.
    
    Args:
        white_surf: the white/gray boundary surface.
        fiber_file: the fiber orientation file.
        max_dist: the maximum distance from any surface vertex a fiber\
            population may be, in mm.
        direction: test against surface for whether a fiber population should\
            be used.
        dot_metric: the metric of dot products.
        f_metric: a metric of the f values of the fiber distributions.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/fiber-dot-products",
        "white_surf": white_surf,
        "fiber_file": fiber_file,
        "max_dist": max_dist,
        "direction": direction,
        "dot_metric": dot_metric,
        "f_metric": f_metric,
    }
    return params


def fiber_dot_products_cargs(
    params: FiberDotProductsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-fiber-dot-products")
    cargs.append(execution.input_file(params.get("white_surf", None)))
    cargs.append(execution.input_file(params.get("fiber_file", None)))
    cargs.append(str(params.get("max_dist", None)))
    cargs.append(params.get("direction", None))
    cargs.append(params.get("dot_metric", None))
    cargs.append(params.get("f_metric", None))
    return cargs


def fiber_dot_products_outputs(
    params: FiberDotProductsParameters,
    execution: Execution,
) -> FiberDotProductsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = FiberDotProductsOutputs(
        root=execution.output_file("."),
        dot_metric=execution.output_file(params.get("dot_metric", None)),
        f_metric=execution.output_file(params.get("f_metric", None)),
    )
    return ret


def fiber_dot_products_execute(
    params: FiberDotProductsParameters,
    runner: Runner | None = None,
) -> FiberDotProductsOutputs:
    """
    fiber-dot-products
    
    Compute dot products of fiber orientations with surface normals.
    
    For each vertex, this command finds the closest fiber population that
    satisfies the <direction> test, and computes the absolute value of the dot
    product of the surface normal and the normalized mean direction of each
    fiber. The <direction> test must be one of INSIDE, OUTSIDE, or ANY, which
    causes the command to only use fiber populations that are inside the
    surface, outside the surface, or to not care which direction it is from the
    surface. Each fiber population is output in a separate metric column.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FiberDotProductsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIBER_DOT_PRODUCTS_METADATA)
    params = execution.params(params)
    cargs = fiber_dot_products_cargs(params, execution)
    ret = fiber_dot_products_outputs(params, execution)
    execution.run(cargs)
    return ret


def fiber_dot_products(
    white_surf: InputPathType,
    fiber_file: InputPathType,
    max_dist: float,
    direction: str,
    dot_metric: str,
    f_metric: str,
    runner: Runner | None = None,
) -> FiberDotProductsOutputs:
    """
    fiber-dot-products
    
    Compute dot products of fiber orientations with surface normals.
    
    For each vertex, this command finds the closest fiber population that
    satisfies the <direction> test, and computes the absolute value of the dot
    product of the surface normal and the normalized mean direction of each
    fiber. The <direction> test must be one of INSIDE, OUTSIDE, or ANY, which
    causes the command to only use fiber populations that are inside the
    surface, outside the surface, or to not care which direction it is from the
    surface. Each fiber population is output in a separate metric column.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        white_surf: the white/gray boundary surface.
        fiber_file: the fiber orientation file.
        max_dist: the maximum distance from any surface vertex a fiber\
            population may be, in mm.
        direction: test against surface for whether a fiber population should\
            be used.
        dot_metric: the metric of dot products.
        f_metric: a metric of the f values of the fiber distributions.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FiberDotProductsOutputs`).
    """
    params = fiber_dot_products_params(
        white_surf=white_surf,
        fiber_file=fiber_file,
        max_dist=max_dist,
        direction=direction,
        dot_metric=dot_metric,
        f_metric=f_metric,
    )
    return fiber_dot_products_execute(params, runner)


__all__ = [
    "FIBER_DOT_PRODUCTS_METADATA",
    "FiberDotProductsOutputs",
    "fiber_dot_products",
    "fiber_dot_products_execute",
    "fiber_dot_products_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_VERTEX_AREAS_METADATA = Metadata(
    id="2ce95b755322be2b857b320aad4cfef1152d88c0.boutiques",
    name="surface-vertex-areas",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceVertexAreasParameters = typing.TypedDict('SurfaceVertexAreasParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-vertex-areas"]],
    "surface": InputPathType,
    "metric": str,
})
SurfaceVertexAreasParametersTagged = typing.TypedDict('SurfaceVertexAreasParametersTagged', {
    "@type": typing.Literal["workbench/surface-vertex-areas"],
    "surface": InputPathType,
    "metric": str,
})


class SurfaceVertexAreasOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceVertexAreasParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric: OutputPathType
    """the output metric"""


def surface_vertex_areas_params(
    surface: InputPathType,
    metric: str,
) -> SurfaceVertexAreasParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to measure.
        metric: the output metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-vertex-areas",
        "surface": surface,
        "metric": metric,
    }
    return params


def surface_vertex_areas_cargs(
    params: SurfaceVertexAreasParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-vertex-areas")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(params.get("metric", None))
    return cargs


def surface_vertex_areas_outputs(
    params: SurfaceVertexAreasParameters,
    execution: Execution,
) -> SurfaceVertexAreasOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceVertexAreasOutputs(
        root=execution.output_file("."),
        metric=execution.output_file(params.get("metric", None)),
    )
    return ret


def surface_vertex_areas_execute(
    params: SurfaceVertexAreasParameters,
    runner: Runner | None = None,
) -> SurfaceVertexAreasOutputs:
    """
    surface-vertex-areas
    
    Measure surface area each vertex is responsible for.
    
    Each vertex gets one third of the area of each triangle it is a part of.
    Units are mm^2.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceVertexAreasOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_VERTEX_AREAS_METADATA)
    params = execution.params(params)
    cargs = surface_vertex_areas_cargs(params, execution)
    ret = surface_vertex_areas_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_vertex_areas(
    surface: InputPathType,
    metric: str,
    runner: Runner | None = None,
) -> SurfaceVertexAreasOutputs:
    """
    surface-vertex-areas
    
    Measure surface area each vertex is responsible for.
    
    Each vertex gets one third of the area of each triangle it is a part of.
    Units are mm^2.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to measure.
        metric: the output metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceVertexAreasOutputs`).
    """
    params = surface_vertex_areas_params(
        surface=surface,
        metric=metric,
    )
    return surface_vertex_areas_execute(params, runner)


__all__ = [
    "SURFACE_VERTEX_AREAS_METADATA",
    "SurfaceVertexAreasOutputs",
    "surface_vertex_areas",
    "surface_vertex_areas_execute",
    "surface_vertex_areas_params",
]



"""
Connectome Workbench

Connectome Workbench is an open source, freely available visualization and
discovery tool used to map neuroimaging data, especially data generated by the
Human Connectome Project. The distribution includes wb_view, a GUI-based
visualiation platform, and wb_command, a command-line program for performing a
variety of algorithmic tasks using volume, surface, and grayordinate data.
wb_command is necessary for running HCP data processing pipelines.

Author: Connectome Workbench Developers

URL: https://github.com/Washington-University/workbench
"""
# This file was auto generated by Styx.
# Do not edit this file directly.

from .add_to_spec_file import *
from .annotation_resample import *
from .backend_average_dense_roi import *
from .backend_average_roi_correlation import *
from .border_export_color_table import *
from .border_file_export_to_caret5 import *
from .border_length import *
from .border_merge import *
from .border_resample import *
from .border_to_rois import *
from .border_to_vertices import *
from .cifti_all_labels_to_rois import *
from .cifti_average import *
from .cifti_average_dense_roi import *
from .cifti_average_roi_correlation import *
from .cifti_change_mapping import *
from .cifti_convert import *
from .cifti_correlation import *
from .cifti_correlation_gradient import *
from .cifti_create_dense_from_template import *
from .cifti_create_dense_scalar import *
from .cifti_create_dense_timeseries import *
from .cifti_create_label import *
from .cifti_create_parcellated_from_template import *
from .cifti_create_scalar_series import *
from .cifti_cross_correlation import *
from .cifti_dilate import *
from .cifti_erode import *
from .cifti_estimate_fwhm import *
from .cifti_export_dense_mapping import *
from .cifti_extrema import *
from .cifti_false_correlation import *
from .cifti_find_clusters import *
from .cifti_gradient import *
from .cifti_label_adjacency import *
from .cifti_label_export_table import *
from .cifti_label_import import *
from .cifti_label_modify_keys import *
from .cifti_label_probability import *
from .cifti_label_to_border import *
from .cifti_label_to_roi import *
from .cifti_math import *
from .cifti_merge import *
from .cifti_merge_dense import *
from .cifti_merge_parcels import *
from .cifti_pairwise_correlation import *
from .cifti_palette import *
from .cifti_parcel_mapping_to_label import *
from .cifti_parcellate import *
from .cifti_reduce import *
from .cifti_reorder import *
from .cifti_replace_structure import *
from .cifti_resample import *
from .cifti_resample_dconn_memory import *
from .cifti_restrict_dense_map import *
from .cifti_roi_average import *
from .cifti_rois_from_extrema import *
from .cifti_separate import *
from .cifti_smoothing import *
from .cifti_stats import *
from .cifti_transpose import *
from .cifti_vector_operation import *
from .cifti_weighted_stats import *
from .convert_affine import *
from .convert_fiber_orientations import *
from .convert_matrix4_to_matrix2 import *
from .convert_matrix4_to_workbench_sparse import *
from .convert_warpfield import *
from .create_signed_distance_volume import *
from .estimate_fiber_binghams import *
from .fiber_dot_products import *
from .file_convert import *
from .file_information import *
from .foci_create import *
from .foci_get_projection_vertex import *
from .foci_list_coords import *
from .foci_resample import *
from .gifti_all_labels_to_rois import *
from .gifti_convert import *
from .gifti_label_add_prefix import *
from .gifti_label_to_roi import *
from .label_dilate import *
from .label_erode import *
from .label_export_table import *
from .label_mask import *
from .label_merge import *
from .label_modify_keys import *
from .label_probability import *
from .label_resample import *
from .label_to_border import *
from .label_to_volume_mapping import *
from .metadata_remove_provenance import *
from .metadata_string_replace import *
from .metric_convert import *
from .metric_dilate import *
from .metric_erode import *
from .metric_estimate_fwhm import *
from .metric_extrema import *
from .metric_false_correlation import *
from .metric_fill_holes import *
from .metric_find_clusters import *
from .metric_gradient import *
from .metric_label_import import *
from .metric_mask import *
from .metric_math import *
from .metric_merge import *
from .metric_palette import *
from .metric_reduce import *
from .metric_regression import *
from .metric_remove_islands import *
from .metric_resample import *
from .metric_rois_from_extrema import *
from .metric_rois_to_border import *
from .metric_smoothing import *
from .metric_stats import *
from .metric_tfce import *
from .metric_to_volume_mapping import *
from .metric_vector_operation import *
from .metric_vector_toward_roi import *
from .metric_weighted_stats import *
from .nifti_information import *
from .probtrackx_dot_convert import *
from .scene_capture_image import *
from .scene_file_merge import *
from .scene_file_relocate import *
from .scene_file_update import *
from .set_map_names import *
from .set_structure import *
from .signed_distance_to_surface import *
from .spec_file_merge import *
from .spec_file_relocate import *
from .surface_affine_regression import *
from .surface_apply_affine import *
from .surface_apply_warpfield import *
from .surface_average import *
from .surface_closest_vertex import *
from .surface_coordinates_to_metric import *
from .surface_cortex_layer import *
from .surface_create_sphere import *
from .surface_curvature import *
from .surface_cut_resample import *
from .surface_distortion import *
from .surface_flip_lr import *
from .surface_flip_normals import *
from .surface_generate_inflated import *
from .surface_geodesic_distance import *
from .surface_geodesic_distance_all_to_all import *
from .surface_geodesic_rois import *
from .surface_inflation import *
from .surface_information import *
from .surface_match import *
from .surface_modify_sphere import *
from .surface_normals import *
from .surface_resample import *
from .surface_set_coordinates import *
from .surface_smoothing import *
from .surface_sphere_project_unproject import *
from .surface_sphere_triangular_patches import *
from .surface_to_surface_3d_distance import *
from .surface_vertex_areas import *
from .surface_wedge_volume import *
from .volume_all_labels_to_rois import *
from .volume_capture_plane import *
from .volume_components_to_frames import *
from .volume_copy_extensions import *
from .volume_create import *
from .volume_dilate import *
from .volume_distortion import *
from .volume_erode import *
from .volume_estimate_fwhm import *
from .volume_extrema import *
from .volume_fill_holes import *
from .volume_find_clusters import *
from .volume_gradient import *
from .volume_label_export_table import *
from .volume_label_import import *
from .volume_label_modify_keys import *
from .volume_label_probability import *
from .volume_label_to_roi import *
from .volume_label_to_surface_mapping import *
from .volume_math import *
from .volume_merge import *
from .volume_palette import *
from .volume_parcel_resampling import *
from .volume_parcel_resampling_generic import *
from .volume_parcel_smoothing import *
from .volume_reduce import *
from .volume_remove_islands import *
from .volume_reorient import *
from .volume_resample import *
from .volume_rois_from_extrema import *
from .volume_set_space import *
from .volume_smoothing import *
from .volume_stats import *
from .volume_tfce import *
from .volume_to_surface_mapping import *
from .volume_vector_operation import *
from .volume_warpfield_affine_regression import *
from .volume_weighted_stats import *
from .wbsparse_merge_dense import *
from .zip_scene_file import *
from .zip_spec_file import *
from styxdefs import Runner as _Runner


def execute(
    params: dict,
    runner: _Runner | None = None,
) -> None:
    """
    Run a command in this package dynamically from a params object.
    
    Args:
        params: The parameters.
        runner: Command runner.
    """
    return {
        "workbench/add-to-spec-file": add_to_spec_file_execute,
        "workbench/annotation-resample": annotation_resample_execute,
        "workbench/backend-average-dense-roi": backend_average_dense_roi_execute,
        "workbench/backend-average-roi-correlation": backend_average_roi_correlation_execute,
        "workbench/border-export-color-table": border_export_color_table_execute,
        "workbench/border-file-export-to-caret5": border_file_export_to_caret5_execute,
        "workbench/border-length": border_length_execute,
        "workbench/border-merge": border_merge_execute,
        "workbench/border-resample": border_resample_execute,
        "workbench/border-to-rois": border_to_rois_execute,
        "workbench/border-to-vertices": border_to_vertices_execute,
        "workbench/cifti-all-labels-to-rois": cifti_all_labels_to_rois_execute,
        "workbench/cifti-average-dense-roi": cifti_average_dense_roi_execute,
        "workbench/cifti-average-roi-correlation": cifti_average_roi_correlation_execute,
        "workbench/cifti-average": cifti_average_execute,
        "workbench/cifti-change-mapping": cifti_change_mapping_execute,
        "workbench/cifti-convert": cifti_convert_execute,
        "workbench/cifti-correlation-gradient": cifti_correlation_gradient_execute,
        "workbench/cifti-correlation": cifti_correlation_execute,
        "workbench/cifti-create-dense-from-template": cifti_create_dense_from_template_execute,
        "workbench/cifti-create-dense-scalar": cifti_create_dense_scalar_execute,
        "workbench/cifti-create-dense-timeseries": cifti_create_dense_timeseries_execute,
        "workbench/cifti-create-label": cifti_create_label_execute,
        "workbench/cifti-create-parcellated-from-template": cifti_create_parcellated_from_template_execute,
        "workbench/cifti-create-scalar-series": cifti_create_scalar_series_execute,
        "workbench/cifti-cross-correlation": cifti_cross_correlation_execute,
        "workbench/cifti-dilate": cifti_dilate_execute,
        "workbench/cifti-erode": cifti_erode_execute,
        "workbench/cifti-estimate-fwhm": cifti_estimate_fwhm_execute,
        "workbench/cifti-export-dense-mapping": cifti_export_dense_mapping_execute,
        "workbench/cifti-extrema": cifti_extrema_execute,
        "workbench/cifti-false-correlation": cifti_false_correlation_execute,
        "workbench/cifti-find-clusters": cifti_find_clusters_execute,
        "workbench/cifti-gradient": cifti_gradient_execute,
        "workbench/cifti-label-adjacency": cifti_label_adjacency_execute,
        "workbench/cifti-label-export-table": cifti_label_export_table_execute,
        "workbench/cifti-label-import": cifti_label_import_execute,
        "workbench/cifti-label-modify-keys": cifti_label_modify_keys_execute,
        "workbench/cifti-label-probability": cifti_label_probability_execute,
        "workbench/cifti-label-to-border": cifti_label_to_border_execute,
        "workbench/cifti-label-to-roi": cifti_label_to_roi_execute,
        "workbench/cifti-math": cifti_math_execute,
        "workbench/cifti-merge-dense": cifti_merge_dense_execute,
        "workbench/cifti-merge-parcels": cifti_merge_parcels_execute,
        "workbench/cifti-merge": cifti_merge_execute,
        "workbench/cifti-pairwise-correlation": cifti_pairwise_correlation_execute,
        "workbench/cifti-palette": cifti_palette_execute,
        "workbench/cifti-parcel-mapping-to-label": cifti_parcel_mapping_to_label_execute,
        "workbench/cifti-parcellate": cifti_parcellate_execute,
        "workbench/cifti-reduce": cifti_reduce_execute,
        "workbench/cifti-reorder": cifti_reorder_execute,
        "workbench/cifti-replace-structure": cifti_replace_structure_execute,
        "workbench/cifti-resample-dconn-memory": cifti_resample_dconn_memory_execute,
        "workbench/cifti-resample": cifti_resample_execute,
        "workbench/cifti-restrict-dense-map": cifti_restrict_dense_map_execute,
        "workbench/cifti-roi-average": cifti_roi_average_execute,
        "workbench/cifti-rois-from-extrema": cifti_rois_from_extrema_execute,
        "workbench/cifti-separate": cifti_separate_execute,
        "workbench/cifti-smoothing": cifti_smoothing_execute,
        "workbench/cifti-stats": cifti_stats_execute,
        "workbench/cifti-transpose": cifti_transpose_execute,
        "workbench/cifti-vector-operation": cifti_vector_operation_execute,
        "workbench/cifti-weighted-stats": cifti_weighted_stats_execute,
        "workbench/convert-affine": convert_affine_execute,
        "workbench/convert-fiber-orientations": convert_fiber_orientations_execute,
        "workbench/convert-matrix4-to-matrix2": convert_matrix4_to_matrix2_execute,
        "workbench/convert-matrix4-to-workbench-sparse": convert_matrix4_to_workbench_sparse_execute,
        "workbench/convert-warpfield": convert_warpfield_execute,
        "workbench/create-signed-distance-volume": create_signed_distance_volume_execute,
        "workbench/estimate-fiber-binghams": estimate_fiber_binghams_execute,
        "workbench/fiber-dot-products": fiber_dot_products_execute,
        "workbench/file-convert": file_convert_execute,
        "workbench/file-information": file_information_execute,
        "workbench/foci-create": foci_create_execute,
        "workbench/foci-get-projection-vertex": foci_get_projection_vertex_execute,
        "workbench/foci-list-coords": foci_list_coords_execute,
        "workbench/foci-resample": foci_resample_execute,
        "workbench/gifti-all-labels-to-rois": gifti_all_labels_to_rois_execute,
        "workbench/gifti-convert": gifti_convert_execute,
        "workbench/gifti-label-add-prefix": gifti_label_add_prefix_execute,
        "workbench/gifti-label-to-roi": gifti_label_to_roi_execute,
        "workbench/label-dilate": label_dilate_execute,
        "workbench/label-erode": label_erode_execute,
        "workbench/label-export-table": label_export_table_execute,
        "workbench/label-mask": label_mask_execute,
        "workbench/label-merge": label_merge_execute,
        "workbench/label-modify-keys": label_modify_keys_execute,
        "workbench/label-probability": label_probability_execute,
        "workbench/label-resample": label_resample_execute,
        "workbench/label-to-border": label_to_border_execute,
        "workbench/label-to-volume-mapping": label_to_volume_mapping_execute,
        "workbench/metadata-remove-provenance": metadata_remove_provenance_execute,
        "workbench/metadata-string-replace": metadata_string_replace_execute,
        "workbench/metric-convert": metric_convert_execute,
        "workbench/metric-dilate": metric_dilate_execute,
        "workbench/metric-erode": metric_erode_execute,
        "workbench/metric-estimate-fwhm": metric_estimate_fwhm_execute,
        "workbench/metric-extrema": metric_extrema_execute,
        "workbench/metric-false-correlation": metric_false_correlation_execute,
        "workbench/metric-fill-holes": metric_fill_holes_execute,
        "workbench/metric-find-clusters": metric_find_clusters_execute,
        "workbench/metric-gradient": metric_gradient_execute,
        "workbench/metric-label-import": metric_label_import_execute,
        "workbench/metric-mask": metric_mask_execute,
        "workbench/metric-math": metric_math_execute,
        "workbench/metric-merge": metric_merge_execute,
        "workbench/metric-palette": metric_palette_execute,
        "workbench/metric-reduce": metric_reduce_execute,
        "workbench/metric-regression": metric_regression_execute,
        "workbench/metric-remove-islands": metric_remove_islands_execute,
        "workbench/metric-resample": metric_resample_execute,
        "workbench/metric-rois-from-extrema": metric_rois_from_extrema_execute,
        "workbench/metric-rois-to-border": metric_rois_to_border_execute,
        "workbench/metric-smoothing": metric_smoothing_execute,
        "workbench/metric-stats": metric_stats_execute,
        "workbench/metric-tfce": metric_tfce_execute,
        "workbench/metric-to-volume-mapping": metric_to_volume_mapping_execute,
        "workbench/metric-vector-operation": metric_vector_operation_execute,
        "workbench/metric-vector-toward-roi": metric_vector_toward_roi_execute,
        "workbench/metric-weighted-stats": metric_weighted_stats_execute,
        "workbench/nifti-information": nifti_information_execute,
        "workbench/probtrackx-dot-convert": probtrackx_dot_convert_execute,
        "workbench/scene-capture-image": scene_capture_image_execute,
        "workbench/scene-file-merge": scene_file_merge_execute,
        "workbench/scene-file-relocate": scene_file_relocate_execute,
        "workbench/scene-file-update": scene_file_update_execute,
        "workbench/set-map-names": set_map_names_execute,
        "workbench/set-structure": set_structure_execute,
        "workbench/signed-distance-to-surface": signed_distance_to_surface_execute,
        "workbench/spec-file-merge": spec_file_merge_execute,
        "workbench/spec-file-relocate": spec_file_relocate_execute,
        "workbench/surface-affine-regression": surface_affine_regression_execute,
        "workbench/surface-apply-affine": surface_apply_affine_execute,
        "workbench/surface-apply-warpfield": surface_apply_warpfield_execute,
        "workbench/surface-average": surface_average_execute,
        "workbench/surface-closest-vertex": surface_closest_vertex_execute,
        "workbench/surface-coordinates-to-metric": surface_coordinates_to_metric_execute,
        "workbench/surface-cortex-layer": surface_cortex_layer_execute,
        "workbench/surface-create-sphere": surface_create_sphere_execute,
        "workbench/surface-curvature": surface_curvature_execute,
        "workbench/surface-cut-resample": surface_cut_resample_execute,
        "workbench/surface-distortion": surface_distortion_execute,
        "workbench/surface-flip-lr": surface_flip_lr_execute,
        "workbench/surface-flip-normals": surface_flip_normals_execute,
        "workbench/surface-generate-inflated": surface_generate_inflated_execute,
        "workbench/surface-geodesic-distance-all-to-all": surface_geodesic_distance_all_to_all_execute,
        "workbench/surface-geodesic-distance": surface_geodesic_distance_execute,
        "workbench/surface-geodesic-rois": surface_geodesic_rois_execute,
        "workbench/surface-inflation": surface_inflation_execute,
        "workbench/surface-information": surface_information_execute,
        "workbench/surface-match": surface_match_execute,
        "workbench/surface-modify-sphere": surface_modify_sphere_execute,
        "workbench/surface-normals": surface_normals_execute,
        "workbench/surface-resample": surface_resample_execute,
        "workbench/surface-set-coordinates": surface_set_coordinates_execute,
        "workbench/surface-smoothing": surface_smoothing_execute,
        "workbench/surface-sphere-project-unproject": surface_sphere_project_unproject_execute,
        "workbench/surface-sphere-triangular-patches": surface_sphere_triangular_patches_execute,
        "workbench/surface-to-surface-3d-distance": surface_to_surface_3d_distance_execute,
        "workbench/surface-vertex-areas": surface_vertex_areas_execute,
        "workbench/surface-wedge-volume": surface_wedge_volume_execute,
        "workbench/volume-all-labels-to-rois": volume_all_labels_to_rois_execute,
        "workbench/volume-capture-plane": volume_capture_plane_execute,
        "workbench/volume-components-to-frames": volume_components_to_frames_execute,
        "workbench/volume-copy-extensions": volume_copy_extensions_execute,
        "workbench/volume-create": volume_create_execute,
        "workbench/volume-dilate": volume_dilate_execute,
        "workbench/volume-distortion": volume_distortion_execute,
        "workbench/volume-erode": volume_erode_execute,
        "workbench/volume-estimate-fwhm": volume_estimate_fwhm_execute,
        "workbench/volume-extrema": volume_extrema_execute,
        "workbench/volume-fill-holes": volume_fill_holes_execute,
        "workbench/volume-find-clusters": volume_find_clusters_execute,
        "workbench/volume-gradient": volume_gradient_execute,
        "workbench/volume-label-export-table": volume_label_export_table_execute,
        "workbench/volume-label-import": volume_label_import_execute,
        "workbench/volume-label-modify-keys": volume_label_modify_keys_execute,
        "workbench/volume-label-probability": volume_label_probability_execute,
        "workbench/volume-label-to-roi": volume_label_to_roi_execute,
        "workbench/volume-label-to-surface-mapping": volume_label_to_surface_mapping_execute,
        "workbench/volume-math": volume_math_execute,
        "workbench/volume-merge": volume_merge_execute,
        "workbench/volume-palette": volume_palette_execute,
        "workbench/volume-parcel-resampling-generic": volume_parcel_resampling_generic_execute,
        "workbench/volume-parcel-resampling": volume_parcel_resampling_execute,
        "workbench/volume-parcel-smoothing": volume_parcel_smoothing_execute,
        "workbench/volume-reduce": volume_reduce_execute,
        "workbench/volume-remove-islands": volume_remove_islands_execute,
        "workbench/volume-reorient": volume_reorient_execute,
        "workbench/volume-resample": volume_resample_execute,
        "workbench/volume-rois-from-extrema": volume_rois_from_extrema_execute,
        "workbench/volume-set-space": volume_set_space_execute,
        "workbench/volume-smoothing": volume_smoothing_execute,
        "workbench/volume-stats": volume_stats_execute,
        "workbench/volume-tfce": volume_tfce_execute,
        "workbench/volume-to-surface-mapping": volume_to_surface_mapping_execute,
        "workbench/volume-vector-operation": volume_vector_operation_execute,
        "workbench/volume-warpfield-affine-regression": volume_warpfield_affine_regression_execute,
        "workbench/volume-weighted-stats": volume_weighted_stats_execute,
        "workbench/wbsparse-merge-dense": wbsparse_merge_dense_execute,
        "workbench/zip-scene-file": zip_scene_file_execute,
        "workbench/zip-spec-file": zip_spec_file_execute,
    }[params["@type"]](params, runner)



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_FALSE_CORRELATION_METADATA = Metadata(
    id="4210406d263a91fc208a58736487b73caec3c5a1.boutiques",
    name="metric-false-correlation",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricFalseCorrelationParameters = typing.TypedDict('MetricFalseCorrelationParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-false-correlation"]],
    "surface": InputPathType,
    "metric_in": InputPathType,
    "3d_dist": float,
    "geo_outer": float,
    "geo_inner": float,
    "metric_out": str,
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_dump_text_text_out": typing.NotRequired[str | None],
})
MetricFalseCorrelationParametersTagged = typing.TypedDict('MetricFalseCorrelationParametersTagged', {
    "@type": typing.Literal["workbench/metric-false-correlation"],
    "surface": InputPathType,
    "metric_in": InputPathType,
    "3d_dist": float,
    "geo_outer": float,
    "geo_inner": float,
    "metric_out": str,
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_dump_text_text_out": typing.NotRequired[str | None],
})


class MetricFalseCorrelationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricFalseCorrelationParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_false_correlation_params(
    surface: InputPathType,
    metric_in: InputPathType,
    v_3d_dist: float,
    geo_outer: float,
    geo_inner: float,
    metric_out: str,
    opt_roi_roi_metric: InputPathType | None = None,
    opt_dump_text_text_out: str | None = None,
) -> MetricFalseCorrelationParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to compute geodesic and 3D distance with.
        metric_in: the metric to correlate.
        v_3d_dist: maximum 3D distance to check around each vertex.
        geo_outer: maximum geodesic distance to use for neighboring correlation.
        geo_inner: minimum geodesic distance to use for neighboring correlation.
        metric_out: the output metric.
        opt_roi_roi_metric: select a region of interest that has data: the\
            region, as a metric file.
        opt_dump_text_text_out: dump the raw measures used to a text file: the\
            output text file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-false-correlation",
        "surface": surface,
        "metric_in": metric_in,
        "3d_dist": v_3d_dist,
        "geo_outer": geo_outer,
        "geo_inner": geo_inner,
        "metric_out": metric_out,
    }
    if opt_roi_roi_metric is not None:
        params["opt_roi_roi_metric"] = opt_roi_roi_metric
    if opt_dump_text_text_out is not None:
        params["opt_dump_text_text_out"] = opt_dump_text_text_out
    return params


def metric_false_correlation_cargs(
    params: MetricFalseCorrelationParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-false-correlation")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(execution.input_file(params.get("metric_in", None)))
    cargs.append(str(params.get("3d_dist", None)))
    cargs.append(str(params.get("geo_outer", None)))
    cargs.append(str(params.get("geo_inner", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_roi_roi_metric", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_metric", None))
        ])
    if params.get("opt_dump_text_text_out", None) is not None:
        cargs.extend([
            "-dump-text",
            params.get("opt_dump_text_text_out", None)
        ])
    return cargs


def metric_false_correlation_outputs(
    params: MetricFalseCorrelationParameters,
    execution: Execution,
) -> MetricFalseCorrelationOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricFalseCorrelationOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def metric_false_correlation_execute(
    params: MetricFalseCorrelationParameters,
    runner: Runner | None = None,
) -> MetricFalseCorrelationOutputs:
    """
    metric-false-correlation
    
    Compare correlation locally and across/through sulci/gyri.
    
    For each vertex, compute the average correlation within a range of geodesic
    distances that don't cross a sulcus/gyrus, and the correlation to the
    closest vertex crossing a sulcus/gyrus. A vertex is considered to cross a
    sulcus/gyrus if the 3D distance is less than a third of the geodesic
    distance. The output file contains the ratio between these correlations, and
    some additional maps to help explain the ratio.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricFalseCorrelationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_FALSE_CORRELATION_METADATA)
    params = execution.params(params)
    cargs = metric_false_correlation_cargs(params, execution)
    ret = metric_false_correlation_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_false_correlation(
    surface: InputPathType,
    metric_in: InputPathType,
    v_3d_dist: float,
    geo_outer: float,
    geo_inner: float,
    metric_out: str,
    opt_roi_roi_metric: InputPathType | None = None,
    opt_dump_text_text_out: str | None = None,
    runner: Runner | None = None,
) -> MetricFalseCorrelationOutputs:
    """
    metric-false-correlation
    
    Compare correlation locally and across/through sulci/gyri.
    
    For each vertex, compute the average correlation within a range of geodesic
    distances that don't cross a sulcus/gyrus, and the correlation to the
    closest vertex crossing a sulcus/gyrus. A vertex is considered to cross a
    sulcus/gyrus if the 3D distance is less than a third of the geodesic
    distance. The output file contains the ratio between these correlations, and
    some additional maps to help explain the ratio.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to compute geodesic and 3D distance with.
        metric_in: the metric to correlate.
        v_3d_dist: maximum 3D distance to check around each vertex.
        geo_outer: maximum geodesic distance to use for neighboring correlation.
        geo_inner: minimum geodesic distance to use for neighboring correlation.
        metric_out: the output metric.
        opt_roi_roi_metric: select a region of interest that has data: the\
            region, as a metric file.
        opt_dump_text_text_out: dump the raw measures used to a text file: the\
            output text file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricFalseCorrelationOutputs`).
    """
    params = metric_false_correlation_params(
        surface=surface,
        metric_in=metric_in,
        v_3d_dist=v_3d_dist,
        geo_outer=geo_outer,
        geo_inner=geo_inner,
        metric_out=metric_out,
        opt_roi_roi_metric=opt_roi_roi_metric,
        opt_dump_text_text_out=opt_dump_text_text_out,
    )
    return metric_false_correlation_execute(params, runner)


__all__ = [
    "METRIC_FALSE_CORRELATION_METADATA",
    "MetricFalseCorrelationOutputs",
    "metric_false_correlation",
    "metric_false_correlation_execute",
    "metric_false_correlation_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_CREATE_DENSE_SCALAR_METADATA = Metadata(
    id="9ba9ea5f5543f7bd7ad9a5ecd9cfcec3a37b90da.boutiques",
    name="cifti-create-dense-scalar",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiCreateDenseScalarVolumeParameters = typing.TypedDict('CiftiCreateDenseScalarVolumeParameters', {
    "@type": typing.NotRequired[typing.Literal["volume"]],
    "volume_data": InputPathType,
    "structure_label_volume": InputPathType,
})
CiftiCreateDenseScalarVolumeParametersTagged = typing.TypedDict('CiftiCreateDenseScalarVolumeParametersTagged', {
    "@type": typing.Literal["volume"],
    "volume_data": InputPathType,
    "structure_label_volume": InputPathType,
})


CiftiCreateDenseScalarLeftMetricParameters = typing.TypedDict('CiftiCreateDenseScalarLeftMetricParameters', {
    "@type": typing.NotRequired[typing.Literal["left_metric"]],
    "metric": InputPathType,
    "opt_roi_left_roi_metric": typing.NotRequired[InputPathType | None],
})
CiftiCreateDenseScalarLeftMetricParametersTagged = typing.TypedDict('CiftiCreateDenseScalarLeftMetricParametersTagged', {
    "@type": typing.Literal["left_metric"],
    "metric": InputPathType,
    "opt_roi_left_roi_metric": typing.NotRequired[InputPathType | None],
})


CiftiCreateDenseScalarRightMetricParameters = typing.TypedDict('CiftiCreateDenseScalarRightMetricParameters', {
    "@type": typing.NotRequired[typing.Literal["right_metric"]],
    "metric": InputPathType,
    "opt_roi_right_roi_metric": typing.NotRequired[InputPathType | None],
})
CiftiCreateDenseScalarRightMetricParametersTagged = typing.TypedDict('CiftiCreateDenseScalarRightMetricParametersTagged', {
    "@type": typing.Literal["right_metric"],
    "metric": InputPathType,
    "opt_roi_right_roi_metric": typing.NotRequired[InputPathType | None],
})


CiftiCreateDenseScalarCerebellumMetricParameters = typing.TypedDict('CiftiCreateDenseScalarCerebellumMetricParameters', {
    "@type": typing.NotRequired[typing.Literal["cerebellum_metric"]],
    "metric": InputPathType,
    "opt_roi_cerebellum_roi_metric": typing.NotRequired[InputPathType | None],
})
CiftiCreateDenseScalarCerebellumMetricParametersTagged = typing.TypedDict('CiftiCreateDenseScalarCerebellumMetricParametersTagged', {
    "@type": typing.Literal["cerebellum_metric"],
    "metric": InputPathType,
    "opt_roi_cerebellum_roi_metric": typing.NotRequired[InputPathType | None],
})


CiftiCreateDenseScalarParameters = typing.TypedDict('CiftiCreateDenseScalarParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-create-dense-scalar"]],
    "cifti_out": str,
    "volume": typing.NotRequired[CiftiCreateDenseScalarVolumeParameters | None],
    "left_metric": typing.NotRequired[CiftiCreateDenseScalarLeftMetricParameters | None],
    "right_metric": typing.NotRequired[CiftiCreateDenseScalarRightMetricParameters | None],
    "cerebellum_metric": typing.NotRequired[CiftiCreateDenseScalarCerebellumMetricParameters | None],
    "opt_name_file_file": typing.NotRequired[str | None],
})
CiftiCreateDenseScalarParametersTagged = typing.TypedDict('CiftiCreateDenseScalarParametersTagged', {
    "@type": typing.Literal["workbench/cifti-create-dense-scalar"],
    "cifti_out": str,
    "volume": typing.NotRequired[CiftiCreateDenseScalarVolumeParameters | None],
    "left_metric": typing.NotRequired[CiftiCreateDenseScalarLeftMetricParameters | None],
    "right_metric": typing.NotRequired[CiftiCreateDenseScalarRightMetricParameters | None],
    "cerebellum_metric": typing.NotRequired[CiftiCreateDenseScalarCerebellumMetricParameters | None],
    "opt_name_file_file": typing.NotRequired[str | None],
})


def cifti_create_dense_scalar_volume_params(
    volume_data: InputPathType,
    structure_label_volume: InputPathType,
) -> CiftiCreateDenseScalarVolumeParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_data: volume file containing all voxel data for all volume\
            structures.
        structure_label_volume: label volume file containing labels for cifti\
            structures.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "volume",
        "volume_data": volume_data,
        "structure_label_volume": structure_label_volume,
    }
    return params


def cifti_create_dense_scalar_volume_cargs(
    params: CiftiCreateDenseScalarVolumeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-volume")
    cargs.append(execution.input_file(params.get("volume_data", None)))
    cargs.append(execution.input_file(params.get("structure_label_volume", None)))
    return cargs


def cifti_create_dense_scalar_left_metric_params(
    metric: InputPathType,
    opt_roi_left_roi_metric: InputPathType | None = None,
) -> CiftiCreateDenseScalarLeftMetricParametersTagged:
    """
    Build parameters.
    
    Args:
        metric: the metric file.
        opt_roi_left_roi_metric: roi of vertices to use from left surface: the\
            ROI as a metric file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "left_metric",
        "metric": metric,
    }
    if opt_roi_left_roi_metric is not None:
        params["opt_roi_left_roi_metric"] = opt_roi_left_roi_metric
    return params


def cifti_create_dense_scalar_left_metric_cargs(
    params: CiftiCreateDenseScalarLeftMetricParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-left-metric")
    cargs.append(execution.input_file(params.get("metric", None)))
    if params.get("opt_roi_left_roi_metric", None) is not None:
        cargs.extend([
            "-roi-left",
            execution.input_file(params.get("opt_roi_left_roi_metric", None))
        ])
    return cargs


def cifti_create_dense_scalar_right_metric_params(
    metric: InputPathType,
    opt_roi_right_roi_metric: InputPathType | None = None,
) -> CiftiCreateDenseScalarRightMetricParametersTagged:
    """
    Build parameters.
    
    Args:
        metric: the metric file.
        opt_roi_right_roi_metric: roi of vertices to use from right surface:\
            the ROI as a metric file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "right_metric",
        "metric": metric,
    }
    if opt_roi_right_roi_metric is not None:
        params["opt_roi_right_roi_metric"] = opt_roi_right_roi_metric
    return params


def cifti_create_dense_scalar_right_metric_cargs(
    params: CiftiCreateDenseScalarRightMetricParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-right-metric")
    cargs.append(execution.input_file(params.get("metric", None)))
    if params.get("opt_roi_right_roi_metric", None) is not None:
        cargs.extend([
            "-roi-right",
            execution.input_file(params.get("opt_roi_right_roi_metric", None))
        ])
    return cargs


def cifti_create_dense_scalar_cerebellum_metric_params(
    metric: InputPathType,
    opt_roi_cerebellum_roi_metric: InputPathType | None = None,
) -> CiftiCreateDenseScalarCerebellumMetricParametersTagged:
    """
    Build parameters.
    
    Args:
        metric: the metric file.
        opt_roi_cerebellum_roi_metric: roi of vertices to use from right\
            surface: the ROI as a metric file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cerebellum_metric",
        "metric": metric,
    }
    if opt_roi_cerebellum_roi_metric is not None:
        params["opt_roi_cerebellum_roi_metric"] = opt_roi_cerebellum_roi_metric
    return params


def cifti_create_dense_scalar_cerebellum_metric_cargs(
    params: CiftiCreateDenseScalarCerebellumMetricParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cerebellum-metric")
    cargs.append(execution.input_file(params.get("metric", None)))
    if params.get("opt_roi_cerebellum_roi_metric", None) is not None:
        cargs.extend([
            "-roi-cerebellum",
            execution.input_file(params.get("opt_roi_cerebellum_roi_metric", None))
        ])
    return cargs


class CiftiCreateDenseScalarOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiCreateDenseScalarParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_create_dense_scalar_params(
    cifti_out: str,
    volume: CiftiCreateDenseScalarVolumeParameters | None = None,
    left_metric: CiftiCreateDenseScalarLeftMetricParameters | None = None,
    right_metric: CiftiCreateDenseScalarRightMetricParameters | None = None,
    cerebellum_metric: CiftiCreateDenseScalarCerebellumMetricParameters | None = None,
    opt_name_file_file: str | None = None,
) -> CiftiCreateDenseScalarParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_out: the output cifti file.
        volume: volume component.
        left_metric: metric for left surface.
        right_metric: metric for right surface.
        cerebellum_metric: metric for the cerebellum.
        opt_name_file_file: use a text file to set all map names: text file\
            containing map names, one per line.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-create-dense-scalar",
        "cifti_out": cifti_out,
    }
    if volume is not None:
        params["volume"] = volume
    if left_metric is not None:
        params["left_metric"] = left_metric
    if right_metric is not None:
        params["right_metric"] = right_metric
    if cerebellum_metric is not None:
        params["cerebellum_metric"] = cerebellum_metric
    if opt_name_file_file is not None:
        params["opt_name_file_file"] = opt_name_file_file
    return params


def cifti_create_dense_scalar_cargs(
    params: CiftiCreateDenseScalarParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-create-dense-scalar")
    cargs.append(params.get("cifti_out", None))
    if params.get("volume", None) is not None:
        cargs.extend(cifti_create_dense_scalar_volume_cargs(params.get("volume", None), execution))
    if params.get("left_metric", None) is not None:
        cargs.extend(cifti_create_dense_scalar_left_metric_cargs(params.get("left_metric", None), execution))
    if params.get("right_metric", None) is not None:
        cargs.extend(cifti_create_dense_scalar_right_metric_cargs(params.get("right_metric", None), execution))
    if params.get("cerebellum_metric", None) is not None:
        cargs.extend(cifti_create_dense_scalar_cerebellum_metric_cargs(params.get("cerebellum_metric", None), execution))
    if params.get("opt_name_file_file", None) is not None:
        cargs.extend([
            "-name-file",
            params.get("opt_name_file_file", None)
        ])
    return cargs


def cifti_create_dense_scalar_outputs(
    params: CiftiCreateDenseScalarParameters,
    execution: Execution,
) -> CiftiCreateDenseScalarOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiCreateDenseScalarOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_create_dense_scalar_execute(
    params: CiftiCreateDenseScalarParameters,
    runner: Runner | None = None,
) -> CiftiCreateDenseScalarOutputs:
    """
    cifti-create-dense-scalar
    
    Create a cifti dense scalar file.
    
    All input files must have the same number of columns/subvolumes. Only the
    specified components will be in the output cifti file. Map names will be
    taken from one of the input files. At least one component must be specified.
    
    See -volume-label-import and -volume-help for format details of label volume
    files. The structure-label-volume should have some of the label names from
    this list, all other label names will be ignored:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateDenseScalarOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CREATE_DENSE_SCALAR_METADATA)
    params = execution.params(params)
    cargs = cifti_create_dense_scalar_cargs(params, execution)
    ret = cifti_create_dense_scalar_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_create_dense_scalar(
    cifti_out: str,
    volume: CiftiCreateDenseScalarVolumeParameters | None = None,
    left_metric: CiftiCreateDenseScalarLeftMetricParameters | None = None,
    right_metric: CiftiCreateDenseScalarRightMetricParameters | None = None,
    cerebellum_metric: CiftiCreateDenseScalarCerebellumMetricParameters | None = None,
    opt_name_file_file: str | None = None,
    runner: Runner | None = None,
) -> CiftiCreateDenseScalarOutputs:
    """
    cifti-create-dense-scalar
    
    Create a cifti dense scalar file.
    
    All input files must have the same number of columns/subvolumes. Only the
    specified components will be in the output cifti file. Map names will be
    taken from one of the input files. At least one component must be specified.
    
    See -volume-label-import and -volume-help for format details of label volume
    files. The structure-label-volume should have some of the label names from
    this list, all other label names will be ignored:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_out: the output cifti file.
        volume: volume component.
        left_metric: metric for left surface.
        right_metric: metric for right surface.
        cerebellum_metric: metric for the cerebellum.
        opt_name_file_file: use a text file to set all map names: text file\
            containing map names, one per line.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateDenseScalarOutputs`).
    """
    params = cifti_create_dense_scalar_params(
        cifti_out=cifti_out,
        volume=volume,
        left_metric=left_metric,
        right_metric=right_metric,
        cerebellum_metric=cerebellum_metric,
        opt_name_file_file=opt_name_file_file,
    )
    return cifti_create_dense_scalar_execute(params, runner)


__all__ = [
    "CIFTI_CREATE_DENSE_SCALAR_METADATA",
    "CiftiCreateDenseScalarOutputs",
    "cifti_create_dense_scalar",
    "cifti_create_dense_scalar_cerebellum_metric_params",
    "cifti_create_dense_scalar_execute",
    "cifti_create_dense_scalar_left_metric_params",
    "cifti_create_dense_scalar_params",
    "cifti_create_dense_scalar_right_metric_params",
    "cifti_create_dense_scalar_volume_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_REPLACE_STRUCTURE_METADATA = Metadata(
    id="9e5fab03b25c831c74fe583c424f6767cbc548ff.boutiques",
    name="cifti-replace-structure",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiReplaceStructureVolumeAllParameters = typing.TypedDict('CiftiReplaceStructureVolumeAllParameters', {
    "@type": typing.NotRequired[typing.Literal["volume_all"]],
    "volume": InputPathType,
    "opt_from_cropped": bool,
})
CiftiReplaceStructureVolumeAllParametersTagged = typing.TypedDict('CiftiReplaceStructureVolumeAllParametersTagged', {
    "@type": typing.Literal["volume_all"],
    "volume": InputPathType,
    "opt_from_cropped": bool,
})


CiftiReplaceStructureLabelParameters = typing.TypedDict('CiftiReplaceStructureLabelParameters', {
    "@type": typing.NotRequired[typing.Literal["label"]],
    "structure": str,
    "label": InputPathType,
})
CiftiReplaceStructureLabelParametersTagged = typing.TypedDict('CiftiReplaceStructureLabelParametersTagged', {
    "@type": typing.Literal["label"],
    "structure": str,
    "label": InputPathType,
})


CiftiReplaceStructureMetricParameters = typing.TypedDict('CiftiReplaceStructureMetricParameters', {
    "@type": typing.NotRequired[typing.Literal["metric"]],
    "structure": str,
    "metric": InputPathType,
})
CiftiReplaceStructureMetricParametersTagged = typing.TypedDict('CiftiReplaceStructureMetricParametersTagged', {
    "@type": typing.Literal["metric"],
    "structure": str,
    "metric": InputPathType,
})


CiftiReplaceStructureVolumeParameters = typing.TypedDict('CiftiReplaceStructureVolumeParameters', {
    "@type": typing.NotRequired[typing.Literal["volume"]],
    "structure": str,
    "volume": InputPathType,
    "opt_from_cropped": bool,
})
CiftiReplaceStructureVolumeParametersTagged = typing.TypedDict('CiftiReplaceStructureVolumeParametersTagged', {
    "@type": typing.Literal["volume"],
    "structure": str,
    "volume": InputPathType,
    "opt_from_cropped": bool,
})


CiftiReplaceStructureParameters = typing.TypedDict('CiftiReplaceStructureParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-replace-structure"]],
    "cifti": str,
    "direction": str,
    "volume_all": typing.NotRequired[CiftiReplaceStructureVolumeAllParameters | None],
    "opt_discard_unused_labels": bool,
    "opt_label_collision_action": typing.NotRequired[str | None],
    "label": typing.NotRequired[list[CiftiReplaceStructureLabelParameters] | None],
    "metric": typing.NotRequired[list[CiftiReplaceStructureMetricParameters] | None],
    "volume": typing.NotRequired[list[CiftiReplaceStructureVolumeParameters] | None],
})
CiftiReplaceStructureParametersTagged = typing.TypedDict('CiftiReplaceStructureParametersTagged', {
    "@type": typing.Literal["workbench/cifti-replace-structure"],
    "cifti": str,
    "direction": str,
    "volume_all": typing.NotRequired[CiftiReplaceStructureVolumeAllParameters | None],
    "opt_discard_unused_labels": bool,
    "opt_label_collision_action": typing.NotRequired[str | None],
    "label": typing.NotRequired[list[CiftiReplaceStructureLabelParameters] | None],
    "metric": typing.NotRequired[list[CiftiReplaceStructureMetricParameters] | None],
    "volume": typing.NotRequired[list[CiftiReplaceStructureVolumeParameters] | None],
})


def cifti_replace_structure_volume_all_params(
    volume: InputPathType,
    opt_from_cropped: bool = False,
) -> CiftiReplaceStructureVolumeAllParametersTagged:
    """
    Build parameters.
    
    Args:
        volume: the input volume.
        opt_from_cropped: the input is cropped to the size of the data.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "volume_all",
        "volume": volume,
        "opt_from_cropped": opt_from_cropped,
    }
    return params


def cifti_replace_structure_volume_all_cargs(
    params: CiftiReplaceStructureVolumeAllParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-volume-all")
    cargs.append(execution.input_file(params.get("volume", None)))
    if params.get("opt_from_cropped", False):
        cargs.append("-from-cropped")
    return cargs


def cifti_replace_structure_label_params(
    structure: str,
    label: InputPathType,
) -> CiftiReplaceStructureLabelParametersTagged:
    """
    Build parameters.
    
    Args:
        structure: the structure to replace the data of.
        label: the input label file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "label",
        "structure": structure,
        "label": label,
    }
    return params


def cifti_replace_structure_label_cargs(
    params: CiftiReplaceStructureLabelParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-label")
    cargs.append(params.get("structure", None))
    cargs.append(execution.input_file(params.get("label", None)))
    return cargs


def cifti_replace_structure_metric_params(
    structure: str,
    metric: InputPathType,
) -> CiftiReplaceStructureMetricParametersTagged:
    """
    Build parameters.
    
    Args:
        structure: the structure to replace the data of.
        metric: the input metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "metric",
        "structure": structure,
        "metric": metric,
    }
    return params


def cifti_replace_structure_metric_cargs(
    params: CiftiReplaceStructureMetricParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-metric")
    cargs.append(params.get("structure", None))
    cargs.append(execution.input_file(params.get("metric", None)))
    return cargs


def cifti_replace_structure_volume_params(
    structure: str,
    volume: InputPathType,
    opt_from_cropped: bool = False,
) -> CiftiReplaceStructureVolumeParametersTagged:
    """
    Build parameters.
    
    Args:
        structure: the structure to replace the data of.
        volume: the input volume.
        opt_from_cropped: the input is cropped to the size of the component.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "volume",
        "structure": structure,
        "volume": volume,
        "opt_from_cropped": opt_from_cropped,
    }
    return params


def cifti_replace_structure_volume_cargs(
    params: CiftiReplaceStructureVolumeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-volume")
    cargs.append(params.get("structure", None))
    cargs.append(execution.input_file(params.get("volume", None)))
    if params.get("opt_from_cropped", False):
        cargs.append("-from-cropped")
    return cargs


class CiftiReplaceStructureOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiReplaceStructureParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_replace_structure_params(
    cifti: str,
    direction: str,
    volume_all: CiftiReplaceStructureVolumeAllParameters | None = None,
    opt_discard_unused_labels: bool = False,
    opt_label_collision_action: str | None = None,
    label: list[CiftiReplaceStructureLabelParameters] | None = None,
    metric: list[CiftiReplaceStructureMetricParameters] | None = None,
    volume: list[CiftiReplaceStructureVolumeParameters] | None = None,
) -> CiftiReplaceStructureParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti: the cifti to modify.
        direction: which dimension to interpret as a single map, ROW or COLUMN.
        volume_all: replace the data in all volume components.
        opt_discard_unused_labels: when operating on a dlabel file, drop any\
            unused label keys from the label table.
        opt_label_collision_action: how to handle conflicts between label keys:\
            'ERROR', 'LEFT_SURFACE_FIRST', or 'LEGACY', default 'ERROR', use\
            'LEGACY' to match v1.4.2 and earlier.
        label: replace the data in a surface label component.
        metric: replace the data in a surface component.
        volume: replace the data in a volume component.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-replace-structure",
        "cifti": cifti,
        "direction": direction,
        "opt_discard_unused_labels": opt_discard_unused_labels,
    }
    if volume_all is not None:
        params["volume_all"] = volume_all
    if opt_label_collision_action is not None:
        params["opt_label_collision_action"] = opt_label_collision_action
    if label is not None:
        params["label"] = label
    if metric is not None:
        params["metric"] = metric
    if volume is not None:
        params["volume"] = volume
    return params


def cifti_replace_structure_cargs(
    params: CiftiReplaceStructureParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-replace-structure")
    cargs.append(params.get("cifti", None))
    cargs.append(params.get("direction", None))
    if params.get("volume_all", None) is not None:
        cargs.extend(cifti_replace_structure_volume_all_cargs(params.get("volume_all", None), execution))
    if params.get("opt_discard_unused_labels", False):
        cargs.append("-discard-unused-labels")
    if params.get("opt_label_collision_action", None) is not None:
        cargs.extend([
            "-label-collision",
            params.get("opt_label_collision_action", None)
        ])
    if params.get("label", None) is not None:
        cargs.extend([a for c in [cifti_replace_structure_label_cargs(s, execution) for s in params.get("label", None)] for a in c])
    if params.get("metric", None) is not None:
        cargs.extend([a for c in [cifti_replace_structure_metric_cargs(s, execution) for s in params.get("metric", None)] for a in c])
    if params.get("volume", None) is not None:
        cargs.extend([a for c in [cifti_replace_structure_volume_cargs(s, execution) for s in params.get("volume", None)] for a in c])
    return cargs


def cifti_replace_structure_outputs(
    params: CiftiReplaceStructureParameters,
    execution: Execution,
) -> CiftiReplaceStructureOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiReplaceStructureOutputs(
        root=execution.output_file("."),
    )
    return ret


def cifti_replace_structure_execute(
    params: CiftiReplaceStructureParameters,
    runner: Runner | None = None,
) -> CiftiReplaceStructureOutputs:
    """
    cifti-replace-structure
    
    Replace data in a structure in a cifti file.
    
    This is a fairly low-level command, you probably want to use
    -cifti-create-dense-from-template instead.
    
    You must specify at least one of -metric, -label, -volume, or -volume-all
    for this command to do anything. Input volumes must line up with the output
    of -cifti-separate. For dtseries/dscalar, use COLUMN, and if your dconn
    matrix will be fully symmetric, COLUMN is more efficient. The -volume-all
    option must not be specified when using a -volume option. A -metric option
    must not be specified when using a -label option, and is not recommended on
    a label-type cifti file. For each <structure> argument, use one of the
    following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiReplaceStructureOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_REPLACE_STRUCTURE_METADATA)
    params = execution.params(params)
    cargs = cifti_replace_structure_cargs(params, execution)
    ret = cifti_replace_structure_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_replace_structure(
    cifti: str,
    direction: str,
    volume_all: CiftiReplaceStructureVolumeAllParameters | None = None,
    opt_discard_unused_labels: bool = False,
    opt_label_collision_action: str | None = None,
    label: list[CiftiReplaceStructureLabelParameters] | None = None,
    metric: list[CiftiReplaceStructureMetricParameters] | None = None,
    volume: list[CiftiReplaceStructureVolumeParameters] | None = None,
    runner: Runner | None = None,
) -> CiftiReplaceStructureOutputs:
    """
    cifti-replace-structure
    
    Replace data in a structure in a cifti file.
    
    This is a fairly low-level command, you probably want to use
    -cifti-create-dense-from-template instead.
    
    You must specify at least one of -metric, -label, -volume, or -volume-all
    for this command to do anything. Input volumes must line up with the output
    of -cifti-separate. For dtseries/dscalar, use COLUMN, and if your dconn
    matrix will be fully symmetric, COLUMN is more efficient. The -volume-all
    option must not be specified when using a -volume option. A -metric option
    must not be specified when using a -label option, and is not recommended on
    a label-type cifti file. For each <structure> argument, use one of the
    following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti: the cifti to modify.
        direction: which dimension to interpret as a single map, ROW or COLUMN.
        volume_all: replace the data in all volume components.
        opt_discard_unused_labels: when operating on a dlabel file, drop any\
            unused label keys from the label table.
        opt_label_collision_action: how to handle conflicts between label keys:\
            'ERROR', 'LEFT_SURFACE_FIRST', or 'LEGACY', default 'ERROR', use\
            'LEGACY' to match v1.4.2 and earlier.
        label: replace the data in a surface label component.
        metric: replace the data in a surface component.
        volume: replace the data in a volume component.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiReplaceStructureOutputs`).
    """
    params = cifti_replace_structure_params(
        cifti=cifti,
        direction=direction,
        volume_all=volume_all,
        opt_discard_unused_labels=opt_discard_unused_labels,
        opt_label_collision_action=opt_label_collision_action,
        label=label,
        metric=metric,
        volume=volume,
    )
    return cifti_replace_structure_execute(params, runner)


__all__ = [
    "CIFTI_REPLACE_STRUCTURE_METADATA",
    "CiftiReplaceStructureOutputs",
    "cifti_replace_structure",
    "cifti_replace_structure_execute",
    "cifti_replace_structure_label_params",
    "cifti_replace_structure_metric_params",
    "cifti_replace_structure_params",
    "cifti_replace_structure_volume_all_params",
    "cifti_replace_structure_volume_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_ERODE_METADATA = Metadata(
    id="e745724b943117f1bea44203e23d97dc9e188367.boutiques",
    name="volume-erode",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeErodeParameters = typing.TypedDict('VolumeErodeParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-erode"]],
    "volume": InputPathType,
    "distance": float,
    "volume_out": str,
    "opt_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "opt_subvolume_subvol": typing.NotRequired[str | None],
})
VolumeErodeParametersTagged = typing.TypedDict('VolumeErodeParametersTagged', {
    "@type": typing.Literal["workbench/volume-erode"],
    "volume": InputPathType,
    "distance": float,
    "volume_out": str,
    "opt_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "opt_subvolume_subvol": typing.NotRequired[str | None],
})


class VolumeErodeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeErodeParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_erode_params(
    volume: InputPathType,
    distance: float,
    volume_out: str,
    opt_roi_roi_volume: InputPathType | None = None,
    opt_subvolume_subvol: str | None = None,
) -> VolumeErodeParametersTagged:
    """
    Build parameters.
    
    Args:
        volume: the volume to erode.
        distance: distance in mm to erode.
        volume_out: the output volume.
        opt_roi_roi_volume: assume voxels outside this roi are nonzero: volume\
            file, positive values denote voxels that have data.
        opt_subvolume_subvol: select a single subvolume to dilate: the\
            subvolume number or name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-erode",
        "volume": volume,
        "distance": distance,
        "volume_out": volume_out,
    }
    if opt_roi_roi_volume is not None:
        params["opt_roi_roi_volume"] = opt_roi_roi_volume
    if opt_subvolume_subvol is not None:
        params["opt_subvolume_subvol"] = opt_subvolume_subvol
    return params


def volume_erode_cargs(
    params: VolumeErodeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-erode")
    cargs.append(execution.input_file(params.get("volume", None)))
    cargs.append(str(params.get("distance", None)))
    cargs.append(params.get("volume_out", None))
    if params.get("opt_roi_roi_volume", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_volume", None))
        ])
    if params.get("opt_subvolume_subvol", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("opt_subvolume_subvol", None)
        ])
    return cargs


def volume_erode_outputs(
    params: VolumeErodeParameters,
    execution: Execution,
) -> VolumeErodeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeErodeOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_erode_execute(
    params: VolumeErodeParameters,
    runner: Runner | None = None,
) -> VolumeErodeOutputs:
    """
    volume-erode
    
    Erode a volume file.
    
    Around each voxel with a value of zero, set surrounding voxels to zero. The
    surrounding voxels are all face neighbors and all voxels within the
    specified distance (center to center).
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeErodeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_ERODE_METADATA)
    params = execution.params(params)
    cargs = volume_erode_cargs(params, execution)
    ret = volume_erode_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_erode(
    volume: InputPathType,
    distance: float,
    volume_out: str,
    opt_roi_roi_volume: InputPathType | None = None,
    opt_subvolume_subvol: str | None = None,
    runner: Runner | None = None,
) -> VolumeErodeOutputs:
    """
    volume-erode
    
    Erode a volume file.
    
    Around each voxel with a value of zero, set surrounding voxels to zero. The
    surrounding voxels are all face neighbors and all voxels within the
    specified distance (center to center).
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume: the volume to erode.
        distance: distance in mm to erode.
        volume_out: the output volume.
        opt_roi_roi_volume: assume voxels outside this roi are nonzero: volume\
            file, positive values denote voxels that have data.
        opt_subvolume_subvol: select a single subvolume to dilate: the\
            subvolume number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeErodeOutputs`).
    """
    params = volume_erode_params(
        volume=volume,
        distance=distance,
        volume_out=volume_out,
        opt_roi_roi_volume=opt_roi_roi_volume,
        opt_subvolume_subvol=opt_subvolume_subvol,
    )
    return volume_erode_execute(params, runner)


__all__ = [
    "VOLUME_ERODE_METADATA",
    "VolumeErodeOutputs",
    "volume_erode",
    "volume_erode_execute",
    "volume_erode_params",
]
